@@ -1,6 +1,6 @@
 package Tie::Array::DBD;
 
-our $VERSION = "0.12";
+our $VERSION = "0.13";
 
 use strict;
 use warnings;
@@ -180,6 +180,7 @@ sub _stream
     $self->{str} or return $val;
 
     $self->{str} eq "Storable" and return nfreeze ({ val => $val });
+    return $val;
     } # _stream
 
 sub _unstream
@@ -189,6 +190,7 @@ sub _unstream
     $self->{str} or return $val;
 
     $self->{str} eq "Storable" and return thaw ($val)->{val};
+    return $val;
     } # _unstream
 
 sub _setmax
@@ -527,7 +529,7 @@ be dropped.
 
 If a table name is provided, it will be checked for existence. If found,
 it will be used with the specified C<key> and C<fld>.  Otherwise it will
-be created with C<key> and <fld>,  but it will not be dropped at the end
+be created with C<key> and C<fld>, but it will not be dropped at the end
 of the session.
 
 =item key
@@ -543,7 +545,8 @@ is C<h_value>.
 =item str
 
 Defines the required persistence module. Currently only supports the use
-of C<Storable>. The default is undefined.
+of C<Storable>.  The default is undefined.  Passing unsupported streamer
+module names will be silently ignored.
 
 Note that C<Storable> does not support persistence of perl types C<CODE>, 
 C<REGEXP>, C<IO>, C<FORMAT>, and C<GLOB>.
@@ -551,6 +554,9 @@ C<REGEXP>, C<IO>, C<FORMAT>, and C<GLOB>.
 If you want to preserve Encoding on the array values, you should use this
 feature.
 
+Also note that this module does not yet support dynamic deep structures.
+See L</Nesting and deep structues>.
+
 =back
 
 =head2 Encoding
@@ -573,6 +579,8 @@ data is restored. To maintain deep structures, use the streamer option:
 
   tie my @array, "Tie::Array::DBD", { str => "Storable" };
 
+Note that changes inside deep structures do not work. See L</TODO>.
+
 =head1 METHODS
 
 =head2 drop ()
@@ -613,6 +621,20 @@ approaches that enable you to fit in your own.
 
 =over 2
 
+=item Update on deep changes
+
+Currently,  nested structures do not get updated when it is an change in
+a deeper part.
+
+  tie my @array, "Tie::Array::DBD", $dbh, { str => "Storable" };
+
+  @array = (
+      [ 1, "foo" ],
+      [ 2, "bar" ],
+      );
+
+  $array[1][0]++; # No effect :(
+
 =item Documentation
 
 Better document what the implications are of storing  I<data> content in
@@ -638,7 +660,7 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-DBI, Tie::DBI, Tie::Hash, Tie::Hash::DBD
+DBI, Tie::DBI, Tie::Hash, Tie::Hash::DBD, DBM::Deep
 
 =cut
 
